@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 __description__ = "Python tool for simply adding startup item by systemd."
 __license__ = "MIT"
 __author__ = "DIYer22"
@@ -72,7 +72,7 @@ def list_all_services():
                 str += f"\n\t{os.path.basename(service_path)}\t{service_path}"
         except:
             pass
-    str = "Services created by add_service:\n" + (str if str else "\tnull")
+    str = "Services created by add_service:" + (str if str else " null")
     return str
 
 
@@ -84,6 +84,18 @@ if __name__ == "__main__":
     ):
         print(list_all_services())
         exit(0)
+
+    if "--rm" in sys.argv:
+        service_names = sys.argv[sys.argv.index("--rm") + 1 :]
+        for service_name in service_names:
+            service_name = service_name.replace(".service", "") + ".service"
+            service_path = f"/etc/systemd/system/{service_name}"
+            assert os.path.isfile(service_path), service_path
+            cmd = f'sudo systemctl stop "{service_name}"; sudo systemctl disable "{service_name}"; sudo rm "{service_path}"'
+            print(f"Remove {service_name} by cmd:\n\t{cmd}")
+            os.system(cmd)
+        exit(0)
+
     if "-h" in sys.argv or "--help" in sys.argv:
         doc = doc + "\n" + list_all_services()
 
@@ -97,12 +109,20 @@ if __name__ == "__main__":
         action="store_true",
         help="List all services created by add_service",
     )
+    parser.add_argument(
+        "--rm",
+        metavar="NAME",
+        default=None,
+        help="Remove the service created by add_service",
+    )
     parser.add_argument(
         "--user",
         default=execmd("whoami"),
         help="User to exec script, default is `whoami`",
     )
-    parser.add_argument("--name", default=None, help="Service name")
+    parser.add_argument(
+        "--name", default=None, help="Service name, default add_service0.service"
+    )
     parser.add_argument(
         "--start", action="store_true", help="Start service immediately"
     )
